pub struct TokenMintMetadata {
pub mint: Mint,
pub program_id: Pubkey,
pub transfer_fee: Option<TransferFee>,
pub transfer_hook_program_id: Option<Pubkey>,
}Expand description
Parsed mint state with metadata fields useful for client code.
Fields
mint: MintUnpacked mint base state.
program_id: PubkeyThe token program that owns this mint.
transfer_fee: Option<TransferFee>Transfer fee configuration if the mint has the TransferFeeConfig extension.
transfer_hook_program_id: Option<Pubkey>Transfer hook program ID if the mint has the TransferHook extension with a non-default program. None otherwise.